==> 1.0.13.tar.gz: lib/implementations/default/dio_connectivity_request_retrier.dart <==
import 'dart:async';
import 'package:connectivity_plus/connectivity_plus.dart';
import 'package:rest_api_client/rest_api_client.dart';

/// Request retrier that executes a previously sent request that failed with a network error.
/// Executes when the connection returns
/// All the rights belong to: https://resocoder.com/2020/03/23/dio-connectivity-retry-interceptor-flutter-tutorial/
class DioConnectivityRequestRetrier {
  final Dio dio;
  late Connectivity connectivity;

  DioConnectivityRequestRetrier({
    required this.dio,
  }) {
    connectivity = Connectivity();
  }

  Future<Response> scheduleRequestRetry(RequestOptions requestOptions) async {
    StreamSubscription? streamSubscription;
    final responseCompleter = Completer<Response>();

    streamSubscription = connectivity.onConnectivityChanged.listen(
      (connectivityResult) async {
        if (connectivityResult != ConnectivityResult.none) {
          streamSubscription?.cancel();
          // Complete the completer instead of returning
          responseCompleter.complete(
            dio.request(
              requestOptions.path,
              cancelToken: requestOptions.cancelToken,
              data: requestOptions.data,
              onReceiveProgress: requestOptions.onReceiveProgress,
              onSendProgress: requestOptions.onSendProgress,
              queryParameters: requestOptions.queryParameters,
              options: Options(
                method: requestOptions.method,
                sendTimeout: requestOptions.sendTimeout,
                receiveTimeout: requestOptions.receiveTimeout,
                extra: requestOptions.extra,
                headers: requestOptions.headers,
                responseType: requestOptions.responseType,
                contentType: requestOptions.contentType,
                validateStatus: requestOptions.validateStatus,
                receiveDataWhenStatusError: requestOptions.receiveDataWhenStatusError,
                followRedirects: requestOptions.followRedirects,
                maxRedirects: requestOptions.maxRedirects,
                requestEncoder: requestOptions.requestEncoder,
                responseDecoder: requestOptions.responseDecoder,
                listFormat: requestOptions.listFormat,
              ),
            ),
          );
        }
      },
    );

    return responseCompleter.future;
  }
}

==> 1.1.15.tar.gz: lib/implementations/default/dio_connectivity_request_retrier.dart <==
import 'dart:async';
import 'package:connectivity_plus/connectivity_plus.dart';
import 'package:rest_api_client/rest_api_client.dart';

/// Request retrier that executes a previously sent request that failed with a network error.
/// Executes when the connection returns
/// All the rights belong to: https://resocoder.com/2020/03/23/dio-connectivity-retry-interceptor-flutter-tutorial/
class DioConnectivityRequestRetrier {
  final Dio dio;
  late Connectivity connectivity;

  DioConnectivityRequestRetrier({
    required this.dio,
  }) {
    connectivity = Connectivity();
  }

  Future<Response> scheduleRequestRetry(RequestOptions requestOptions) async {
    StreamSubscription? streamSubscription;
    final responseCompleter = Completer<Response>();

    streamSubscription = connectivity.onConnectivityChanged.listen(
      (connectivityResult) async {
        if (connectivityResult != ConnectivityResult.none) {
          streamSubscription?.cancel();
          // Complete the completer instead of returning
          responseCompleter.complete(
            dio.request(
              requestOptions.path,
              cancelToken: requestOptions.cancelToken,
              data: requestOptions.data,
              onReceiveProgress: requestOptions.onReceiveProgress,
              onSendProgress: requestOptions.onSendProgress,
              queryParameters: requestOptions.queryParameters,
              options: Options(
                method: requestOptions.method,
                sendTimeout: requestOptions.sendTimeout,
                receiveTimeout: requestOptions.receiveTimeout,
                extra: requestOptions.extra,
                headers: requestOptions.headers,
                responseType: requestOptions.responseType,
                contentType: requestOptions.contentType,
                validateStatus: requestOptions.validateStatus,
                receiveDataWhenStatusError:
                    requestOptions.receiveDataWhenStatusError,
                followRedirects: requestOptions.followRedirects,
                maxRedirects: requestOptions.maxRedirects,
                requestEncoder: requestOptions.requestEncoder,
                responseDecoder: requestOptions.responseDecoder,
                listFormat: requestOptions.listFormat,
              ),
            ),
          );
        }
      },
    );

    return responseCompleter.future;
  }
}
